@@ -777,5 +777,8 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             )
         return self._stubs["list_worker_pools"]
 
+    def close(self):
+        self.grpc_channel.close()
+
 
 __all__ = ("CloudBuildGrpcTransport",)
