@@ -14,9 +14,13 @@
 # limitations under the License.
 #
 from .cloudbuild import (
+    ApprovalConfig,
+    ApprovalResult,
+    ApproveBuildRequest,
     ArtifactResult,
     Artifacts,
     Build,
+    BuildApproval,
     BuildOperationMetadata,
     BuildOptions,
     BuildStep,
@@ -25,8 +29,10 @@ from .cloudbuild import (
     CancelBuildRequest,
     CreateBuildRequest,
     CreateBuildTriggerRequest,
+    CreateWorkerPoolOperationMetadata,
     CreateWorkerPoolRequest,
     DeleteBuildTriggerRequest,
+    DeleteWorkerPoolOperationMetadata,
     DeleteWorkerPoolRequest,
     FileHashes,
     GetBuildRequest,
@@ -41,7 +47,7 @@ from .cloudbuild import (
     ListBuildTriggersResponse,
     ListWorkerPoolsRequest,
     ListWorkerPoolsResponse,
-    Network,
+    PrivatePoolV1Config,
     PubsubConfig,
     PullRequestFilter,
     PushFilter,
@@ -60,16 +66,21 @@ from .cloudbuild import (
     StorageSourceManifest,
     TimeSpan,
     UpdateBuildTriggerRequest,
+    UpdateWorkerPoolOperationMetadata,
     UpdateWorkerPoolRequest,
     Volume,
-    WorkerConfig,
+    WebhookConfig,
     WorkerPool,
 )
 
 __all__ = (
+    "ApprovalConfig",
+    "ApprovalResult",
+    "ApproveBuildRequest",
     "ArtifactResult",
     "Artifacts",
     "Build",
+    "BuildApproval",
     "BuildOperationMetadata",
     "BuildOptions",
     "BuildStep",
@@ -78,8 +89,10 @@ __all__ = (
     "CancelBuildRequest",
     "CreateBuildRequest",
     "CreateBuildTriggerRequest",
+    "CreateWorkerPoolOperationMetadata",
     "CreateWorkerPoolRequest",
     "DeleteBuildTriggerRequest",
+    "DeleteWorkerPoolOperationMetadata",
     "DeleteWorkerPoolRequest",
     "FileHashes",
     "GetBuildRequest",
@@ -94,7 +107,7 @@ __all__ = (
     "ListBuildTriggersResponse",
     "ListWorkerPoolsRequest",
     "ListWorkerPoolsResponse",
-    "Network",
+    "PrivatePoolV1Config",
     "PubsubConfig",
     "PullRequestFilter",
     "PushFilter",
@@ -113,8 +126,9 @@ __all__ = (
     "StorageSourceManifest",
     "TimeSpan",
     "UpdateBuildTriggerRequest",
+    "UpdateWorkerPoolOperationMetadata",
     "UpdateWorkerPoolRequest",
     "Volume",
-    "WorkerConfig",
+    "WebhookConfig",
     "WorkerPool",
 )
